Structs
- Aggregate
Star - Flag aggregate functions other than COUNT that use
*as their argument (e.g.,SUM(*),AVG(*),MIN(*),MAX(*)). OnlyCOUNT(*)is valid SQL; using*with other aggregates is almost always a typo or logic error.
* as their argument
(e.g., SUM(*), AVG(*), MIN(*), MAX(*)). Only COUNT(*) is valid
SQL; using * with other aggregates is almost always a typo or logic error.