pub struct HavingConditionsCount {
pub max_conditions: usize,
}Fields
max_conditions: usizeMaximum number of conditions allowed in a HAVING clause. A clause with N conditions is connected by N-1 AND/OR operators. When the condition count exceeds this maximum the clause is flagged.